==> drd-4.0.4.tar.gz: drd/src/Update/Manager.php <==
<?php

namespace Drupal\drd\Update;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\drd\Annotation\Update;
use Traversable;

/**
 * Manages discovery and instantiation of DRD Update plugins.
 */
abstract class Manager extends DefaultPluginManager implements ManagerInterface {

  /**
   * @var array
   */
  private $selectList;

  /**
   * Constructs a new \Drupal\drd\Update\Manager object.
   *
   * @param \Traversable $namespaces
   *   An object that implements \Traversable which contains the root paths
   *   keyed by the corresponding namespace to look for plugin implementations.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   Cache backend instance to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler to invoke the alter hook with.
   */
  public function __construct(Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler) {
    parent::__construct($this->getSubDir(), $namespaces, $module_handler, $this->getPluginInterface(), Update::class);

    $this->alterInfo('drd_update');
    $this->setCacheBackend($cache_backend, 'drd_update_plugins_' . $this->getType());
  }

  /**
   * {@inheritdoc}
   */
  public function getSelect(): array {
    if (!isset($this->selectList)) {
      $this->selectList = [];
      foreach ($this->getDefinitions() as $def) {
        $this->selectList[$def['id']] = $def['admin_label'];
      }
    }
    return $this->selectList;
  }

}

==> drd-4.1.2.tar.gz: drd/src/Update/Manager.php <==
<?php

namespace Drupal\drd\Update;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\drd\Annotation\Update;

/**
 * Manages discovery and instantiation of DRD Update plugins.
 */
abstract class Manager extends DefaultPluginManager implements ManagerInterface {

  /**
   * The list of update plugins.
   *
   * @var array|null
   */
  private ?array $selectList = NULL;

  /**
   * Constructs a new \Drupal\drd\Update\Manager object.
   *
   * @param \Traversable $namespaces
   *   An object that implements \Traversable which contains the root paths
   *   keyed by the corresponding namespace to look for plugin implementations.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   Cache backend instance to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler to invoke the alter hook with.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler) {
    parent::__construct($this->getSubDir(), $namespaces, $module_handler, $this->getPluginInterface(), Update::class);

    $this->alterInfo('drd_update');
    $this->setCacheBackend($cache_backend, 'drd_update_plugins_' . $this->getType());
  }

  /**
   * {@inheritdoc}
   */
  public function getSelect(): array {
    if ($this->selectList === NULL) {
      $this->selectList = [];
      foreach ($this->getDefinitions() as $def) {
        $this->selectList[$def['id']] = $def['admin_label'];
      }
    }
    return $this->selectList;
  }

}
